@@ -49,7 +49,7 @@ void recursive_transfer(const KArchiveDirectory *dir, const QString &path, KZip
             printf("FILE=%s\n", qPrintable(e->name()));
 
             QByteArray arr(f->data());
-            printf("SIZE=%i\n", arr.size());
+            printf("SIZE=%lli\n", arr.size());
             QString str(arr);
             printf("DATA=%s\n", qPrintable(str));
 
@@ -68,7 +68,7 @@ static int doList(const QString &fileName)
 {
     KZip zip(fileName);
     if (!zip.open(QIODevice::ReadOnly)) {
-        qWarning() << "Could not open" << fileName << "for reading. ZIP file doesn't exist or is invalid.";
+        qWarning() << "Could not open" << fileName << "for reading. ZIP file doesn't exist or is invalid:" << zip.errorString();
         return 1;
     }
     const KArchiveDirectory *dir = zip.directory();
@@ -82,7 +82,7 @@ static int doPrintAll(const QString &fileName)
     KZip zip(fileName);
     qDebug() << "Opening zip file";
     if (!zip.open(QIODevice::ReadOnly)) {
-        qWarning() << "Could not open" << fileName << "for reading. ZIP file doesn't exist or is invalid.";
+        qWarning() << "Could not open" << fileName << "for reading. ZIP file doesn't exist or is invalid:" << zip.errorString();
         return 1;
     }
     const KArchiveDirectory *dir = zip.directory();
@@ -95,7 +95,7 @@ static int doPrintAll(const QString &fileName)
             Q_ASSERT(e && e->isFile());
             const KArchiveFile *f = static_cast<const KArchiveFile *>(e);
             const QByteArray data(f->data());
-            printf("SIZE=%i\n", data.size());
+            printf("SIZE=%lli\n", data.size());
             QString str = QString::fromUtf8(data);
             printf("DATA=%s\n", qPrintable(str));
         }
@@ -108,7 +108,7 @@ static int doSave(const QString &fileName)
 {
     KZip zip(fileName);
     if (!zip.open(QIODevice::WriteOnly)) {
-        qWarning() << "Could not open" << fileName << "for writing";
+        qWarning() << "Could not open" << fileName << "for writing:" << zip.errorString();
         return 1;
     }
 
@@ -136,7 +136,7 @@ static int doLoad(const QString &fileName)
 {
     KZip zip(fileName);
     if (!zip.open(QIODevice::ReadOnly)) {
-        qWarning() << "Could not open" << fileName << "for reading. ZIP file doesn't exist or is invalid.";
+        qWarning() << "Could not open" << fileName << "for reading. ZIP file doesn't exist or is invalid:" << zip.errorString();
         return 1;
     }
     const KArchiveDirectory *dir = zip.directory();
@@ -151,7 +151,7 @@ static int doPrint(const QString &fileName, const QString &entryName)
 {
     KZip zip(fileName);
     if (!zip.open(QIODevice::ReadOnly)) {
-        qWarning() << "Could not open" << fileName << "for reading. ZIP file doesn't exist or is invalid.";
+        qWarning() << "Could not open" << fileName << "for reading. ZIP file doesn't exist or is invalid:" << zip.errorString();
         return 1;
     }
     const KArchiveDirectory *dir = zip.directory();
@@ -160,7 +160,8 @@ static int doPrint(const QString &fileName, const QString &entryName)
     const KArchiveFile *f = static_cast<const KArchiveFile *>(e);
 
     const QByteArray arr(f->data());
-    printf("SIZE=%i\n", arr.size());
+    printf("SIZE=%lli\n", arr.size());
+
     QString str = QString::fromUtf8(arr);
     printf("%s", qPrintable(str));
     return zip.close() ? 0 : 1 /*error*/;
@@ -170,13 +171,13 @@ static int doCreate(const QString &archiveName, const QStringList &fileNames)
 {
     KZip zip(archiveName);
     if (!zip.open(QIODevice::WriteOnly)) {
-        qWarning() << "Could not open" << archiveName << "for writing";
+        qWarning() << "Could not open" << archiveName << "for writing:" << zip.errorString();
         return 1;
     }
     for (const QString &fileName : fileNames) {
         QFile f(fileName);
         if (!f.open(QIODevice::ReadOnly)) {
-            qWarning() << "Could not open" << fileName << "for reading.";
+            qWarning() << "Could not open" << fileName << "for reading:" << zip.errorString();
             return 1;
         }
         zip.writeFile(fileName, f.readAll());
@@ -188,13 +189,13 @@ static int doUpdate(const QString &archiveName, const QString &fileName)
 {
     KZip zip(archiveName);
     if (!zip.open(QIODevice::ReadWrite)) {
-        qWarning() << "Could not open" << archiveName << "for read/write";
+        qWarning() << "Could not open" << archiveName << "for read/write:" << zip.errorString();
         return 1;
     }
 
     QFile f(fileName);
     if (!f.open(QIODevice::ReadOnly)) {
-        qWarning() << "Could not open" << fileName << "for reading.";
+        qWarning() << "Could not open" << fileName << "for reading:" << zip.errorString();
         return 1;
     }
 
@@ -207,11 +208,11 @@ static int doTransfer(const QString &sourceFile, const QString &destFile)
     KZip zip1(sourceFile);
     KZip zip2(destFile);
     if (!zip1.open(QIODevice::ReadOnly)) {
-        qWarning() << "Could not open" << sourceFile << "for reading. ZIP file doesn't exist or is invalid.";
+        qWarning() << "Could not open" << sourceFile << "for reading. ZIP file doesn't exist or is invalid:" << zip1.errorString();
         return 1;
     }
     if (!zip2.open(QIODevice::WriteOnly)) {
-        qWarning() << "Could not open" << destFile << "for writing";
+        qWarning() << "Could not open" << destFile << "for writing:" << zip2.errorString();
         return 1;
     }
     const KArchiveDirectory *dir1 = zip1.directory();
@@ -239,7 +240,7 @@ static int doCompress(const QString &fileName)
 {
     KCompressionDevice device(fileName, KCompressionDevice::BZip2);
     if (!device.open(QIODevice::WriteOnly)) {
-        qWarning() << "Could not open" << fileName << "for writing";
+        qWarning() << "Could not open" << fileName << "for writing:" << device.errorString();
         return 1;
     }
 
@@ -257,7 +258,7 @@ static int doUncompress(const QString &fileName)
 {
     KCompressionDevice device(fileName, KCompressionDevice::BZip2);
     if (!device.open(QIODevice::ReadOnly)) {
-        qWarning() << "Could not open" << fileName << "for reading";
+        qWarning() << "Could not open" << fileName << "for reading:" << device.errorString();
         return 1;
     }
     return load(&device);
